/**
 * Copyright (c) 2013-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.extension.command.monitoring;

import java.util.Arrays;
import java.util.List;

import org.apache.commons.cli.Option;
import org.apache.commons.cli.Options;
import org.ow2.petals.cli.api.shell.Shell;
import org.ow2.petals.cli.extension.command.monitoring.mo.api.MonitoringObject;
import org.ow2.petals.cli.extension.command.monitoring.mo.api.MonitoringSubFunction;
import org.ow2.petals.cli.extension.command.monitoring.mo.api.exception.MonitoringSubFunctionException;

/**
 * 
 * <p>
 * Dummy monitoring object for unit test purpose with following characteristics:
 * </p>
 * <ul>
 * <li>without description,</li>
 * <li>a unique dummy monitoring sub-function with arguments but without
 * description.</li>
 * </ul>
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class DummyMOWithArgs implements MonitoringObject {

    public final static String NAME = "dummy-mo";

    public final static String SUBFCT_NAME = "dummy-fct";

    /**
     * An optional dummy argument of the monitoring sub-function.
     */
    public static final String DUMMY_SHORT_OPTION = "d";

    private static final String DUMMY_LONG_OPTION = "dummy";

    private static final String DUMMY_ARG_NAME = "dummy";

    private static final String DUMMY_OPTION_DESCR = "An optional dummy argument of the monitoring sub-function.";

    private static final Option DUMMY_OPTION = Option.builder(DUMMY_SHORT_OPTION).longOpt(DUMMY_LONG_OPTION)
            .required(false).numberOfArgs(1).argName(DUMMY_ARG_NAME).desc(DUMMY_OPTION_DESCR).build();

    private class DummySubFunction implements MonitoringSubFunction {

        /**
         * The command options
         */
        private Options options;

        public DummySubFunction() {
            this.createOptions();
        }

        @Override
        public String getName() {
            return SUBFCT_NAME;
        }

        @Override
        public String getDescription() {
            return null;
        }

        @Override
        public Options getOptions() {
            return this.options;
        }

        @Override
        public void execute(final String[] args) throws MonitoringSubFunctionException {
        }

        @Override
        public void setShell(final Shell shell) {
        }

        @Override
        public void resetOptions() {
            this.createOptions();
        }

        @Override
        public Shell getShell() {
            return null;
        }

        private void createOptions() {
            this.options = new Options();
            this.options.addOption(DUMMY_OPTION);
        }

    }

    private final MonitoringSubFunction[] SUBFUNCTIONS = new MonitoringSubFunction[] { new DummySubFunction() };

    @Override
    public List<MonitoringSubFunction> getSubFunctions() {
        return Arrays.asList(SUBFUNCTIONS);
    }

    @Override
    public String getName() {
        return NAME;
    }

    @Override
    public String getDescription() {
        return "A dummy monitoring object description";
    }

}
